## [1.0.1](https://github.com/seba-ban/env-var/compare/v1.0.0...v1.0.1) (2022-04-18)


### Bug Fixes

* deleted print statement left during development ([a67c653](https://github.com/seba-ban/env-var/commit/a67c6532e1e07f0ef70eb7b3648553c4c793ed68))

# 1.0.0 (2022-04-18)


### Features

* initial release ([#1](https://github.com/seba-ban/env-var/issues/1)) ([251463a](https://github.com/seba-ban/env-var/commit/251463ad323eb90f4e629d5527dfbfa4dfc8ea33))
